CommitMetadata

Struct CommitMetadata 

pub struct CommitMetadata { /* private fields */ }
CommitMetadata bundles the metadata about a commit operation. This includes the commit path, version, and protocol/metadata state of the table being committed to. Catalog committers can use the protocol and metadata getters to validate or inspect the commit.

Note that this struct cannot be constructed. It is handed to the Committer (in the commit method) by the kernel when a transaction is being committed.

See the module-level documentation for more details.

Implementations

Source

impl CommitMetadata

pub fn published_commit_path(&self) -> DeltaResult<Url>

The commit path is the absolute path (e.g. s3://bucket/table/_delta_log/{version}.json) to the published delta file for this commit.

pub fn staged_commit_path(&self) -> DeltaResult<Url>

The staged commit path is the absolute path (e.g. s3://bucket/table/_delta_log/{version}.{uuid}.json) to the staged commit file.

pub fn version(&self) -> Version

The version to which the transaction is being committed.

pub fn commit_type(&self) -> CommitType

The type of commit operation being performed.

pub fn in_commit_timestamp(&self) -> i64

The in-commit timestamp for the commit. Note that this may differ from the actual commit file modification time.

pub fn max_published_version(&self) -> Option<Version>

The maximum published version of the table.

pub fn table_root(&self) -> &Url

The root URL of the table being committed to.

pub fn has_writer_feature(&self, feature_name: &str) -> bool

Check if the effective protocol has a specific writer feature by name.

pub fn has_reader_feature(&self, feature_name: &str) -> bool

Check if the effective protocol has a specific reader feature by name.

pub fn metadata_configuration(&self) -> Option<&HashMap<String, String>>

Get the raw metadata configuration for the effective metadata. Returns None if no metadata is set.

pub fn has_protocol_change(&self) -> bool

Returns true if this commit changes the table’s protocol.

pub fn has_metadata_change(&self) -> bool

Returns true if this commit changes the table’s metadata.

pub fn has_domain_metadata_change(&self, domain: &str) -> bool

Returns true if this commit includes a domain metadata change for the given domain name.

pub fn new_unchecked(table_root: Url, version: Version) -> DeltaResult<Self>

Available on crate features test-utils only.

Creates a new CommitMetadata for the given table_root and version. Test-only.

Uses a default modern protocol (empty features) and empty metadata.

pub fn new_unchecked_with( table_root: Url, version: Version, reader_features: Vec<&str>, writer_features: Vec<&str>, configuration: HashMap<String, String>, ) -> DeltaResult<Self>

Available on crate features test-utils only.

Creates a new CommitMetadata with specific features and configuration. Test-only.

pub fn with_protocol_change(self) -> Self

Available on crate features test-utils only.

Marks this CommitMetadata as having a protocol change. Test-only.

that changes the protocol.

pub fn with_metadata_change(self) -> Self

Available on crate features test-utils only.

Marks this CommitMetadata as having a metadata change. Test-only.

Copies the existing metadata into the new_metadata field to simulate an ALTER TABLE that changes the metadata.

pub fn with_domain_change(self, domain: &str) -> Self

Available on crate features test-utils only.

Adds a domain metadata change for the given domain name. Test-only.

Creates a synthetic domain metadata entry to simulate a domain metadata change (e.g. clustering column change via ALTER TABLE CLUSTER BY).