pub struct PublishMetadata { /* private fields */ }Expand description
Metadata required for publishing catalog commits to the Delta log.
PublishMetadata bundles all the information needed to publish catalog commits: the version up
to which commits should be published, and the list of catalog commits themselves.
Invariants
The following invariants are enforced at construction time:
commits_to_publishmust be non-emptycommits_to_publishmust be contiguous (no version gaps) in ascending order of version- The last catalog commit version must equal
publish_to_version
See Committer::publish for details on the publish operation.
Implementations
Sourceimpl PublishMetadata
impl PublishMetadata
Sourcepub fn try_new(
publish_to_version: Version,
commits_to_publish: Vec<CatalogCommit>,
) -> DeltaResult<Self>
pub fn try_new( publish_to_version: Version, commits_to_publish: Vec<CatalogCommit>, ) -> DeltaResult<Self>
Creates a new PublishMetadata with the given publish to version and catalog commits.
Sourcepub fn publish_version(&self) -> Version
pub fn publish_version(&self) -> Version
The snapshot version up to which all catalog commits must be published.
Sourcepub fn commits_to_publish(&self) -> &[CatalogCommit]
pub fn commits_to_publish(&self) -> &[CatalogCommit]
The list of contiguous catalog commits to be published, in ascending order of version.