Module engine

Module engine 

Available on crate features arrow-conversion or declarative-plans or default-engine-base only.
Engine infrastructure shared by Engine implementations.

The default Arrow/Tokio engine lives in the separate delta_kernel_default_engine crate. SyncEngine is included only in test builds.

Re-exports

pub use self::arrow_utils::parse_json;arrow-expression and internal-api
pub use self::arrow_utils::to_json_bytes;arrow-expression and internal-api

Modules

arrow_conversionarrow-conversion
Conversions between kernel schema types and arrow schema types.
arrow_datadefault-engine-base
arrow_expressionarrow-expression and default-engine-base
Expression handling based on arrow-rs compute kernels.
arrow_utilsarrow-expression and internal-api
Some utilities for working with arrow data types
ensure_data_typesdefault-engine-base and internal-api
Helpers to ensure that kernel data types match arrow data types
parquet_row_group_skippingdefault-engine-base
An implementation of parquet row group skipping using data skipping predicates over footer stats.
plansdeclarative-plans and default-engine-base
This module contains an implementation of the Engine trait that is backed by a PlanExecutor. The engine delegates handler operations (e.g. storage, JSON, parquet) to declarative plan execution rather than implementing each handler independently.

Functions

reader_optionsinternal-api
Returns the standard ArrowReaderOptions for all default engine parquet reads.
writer_optionsinternal-api
Returns the standard ArrowWriterOptions for all kernel parquet writes.