TryFromKernel

Trait TryFromKernel 

pub trait TryFromKernel<KernelType>: Sized {
    // Required method
    fn try_from_kernel(t: KernelType) -> Result<Self, ArrowError>;
}
Available on crate feature arrow-conversion and (crate features arrow-conversion or declarative-plans or default-engine-base) only.
Convert a kernel type into an arrow type (a similar TryIntoArrow trait is automatically implemented for all types that implement TryFromKernel)

Required Methods

fn try_from_kernel(t: KernelType) -> Result<Self, ArrowError>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TryFromKernel<&ArrayType> for Field

Source

impl TryFromKernel<&DataType> for DataType

Source

impl TryFromKernel<&MapType> for Field

Source

impl TryFromKernel<&StructField> for Field

Source

impl TryFromKernel<&StructType> for Schema

Implementors