generate_mask

Function generate_mask 

pub fn generate_mask(
    _requested_schema: &SchemaRef,
    _parquet_schema: &SchemaRef,
    parquet_physical_schema: &SchemaDescriptor,
    indices: &[usize],
) -> Option<ProjectionMask>
Available on crate feature arrow-expression and crate feature internal-api and (crate features arrow-conversion or declarative-plans or default-engine-base) only.
Create a mask that will only select the specified indices from the parquet. indices can be computed from a Schema using get_requested_indices