DefaultEngine

Struct DefaultEngine 

pub struct DefaultEngine<E: TaskExecutor> { /* private fields */ }
Available on (crate features default-engine-native-tls or default-engine-rustls or arrow-conversion) and crate feature default-engine-base only.

Implementations

Source

impl DefaultEngine<TokioBackgroundExecutor>

pub fn builder( object_store: Arc<DynObjectStore>, ) -> DefaultEngineBuilder<TokioBackgroundExecutor>

Create a DefaultEngineBuilder for constructing a DefaultEngine with custom options.

Parameters
  • object_store: The object store to use.
Source

impl<E: TaskExecutor> DefaultEngine<E>

pub fn enter(&self) -> <E as TaskExecutor>::Guard<'_>

Enter the runtime context of the executor associated with this engine.

Panics

When calling enter multiple times, the returned guards must be dropped in the reverse order that they were acquired. Failure to do so will result in a panic and possible memory leaks.

pub fn get_object_store_for_url( &self, _url: &Url, ) -> Option<Arc<DynObjectStore>>

pub async fn write_parquet( &self, data: &ArrowEngineData, write_context: &WriteContext, partition_values: HashMap<String, String>, ) -> DeltaResult<Box<dyn EngineData>>

Write data as a parquet file using the provided write_context.

The partition_values keys should use logical column names. They will be automatically translated to physical names using the column mapping mode from write_context.