FilteredEngineData

Struct FilteredEngineData 

pub struct FilteredEngineData { /* private fields */ }
Engine data paired with a selection vector indicating which rows are logically selected.

A value of true in the selection vector means the corresponding row is selected (i.e., not deleted), while false means the row is logically deleted and should be ignored. If the selection vector is shorter than the number of rows in data then all rows not covered by the selection vector are assumed to be selected.

Interpreting unselected (false) rows will result in incorrect/undefined behavior.

Implementations

Source

impl FilteredEngineData

pub fn try_new( data: Box<dyn EngineData>, selection_vector: Vec<bool>, ) -> DeltaResult<Self>

pub fn data(&self) -> &dyn EngineData

Returns a reference to the underlying engine data.

pub fn selection_vector(&self) -> &[bool]

Returns a reference to the selection vector.

pub fn into_parts(self) -> (Box<dyn EngineData>, Vec<bool>)

Consumes the FilteredEngineData and returns the underlying data and selection vector.

pub fn with_all_rows_selected(data: Box<dyn EngineData>) -> Self

Creates a new FilteredEngineData with all rows selected.

This is a convenience method for the common case where you want to wrap EngineData in FilteredEngineData without any filtering.

pub fn apply_selection_vector(self) -> DeltaResult<Box<dyn EngineData>>

Apply the contained selection vector and return an engine data with only the selected rows included. This consumes the FilteredEngineData.