Module error

Module error 

Definitions of errors that the delta kernel can encounter

Enums

Error
All the types of errors that the kernel can run into

Type Aliases

DeltaResult
A std::result::Result that has the kernel Error as the error variant
DeltaResultIterator
A boxed, Send iterator of DeltaResult<T> items.
DeltaResultIteratorStatic
'static counterpart to DeltaResultIterator for cases where the iterator does not reference borrowed data.