joined_column_name

Macro joined_column_name 

macro_rules! joined_column_name {
    ( $left:literal, $right:literal ) => { ... };
    ( $left:literal, $right:expr ) => { ... };
    ( $left:expr, $right:literal) => { ... };
    ( $($other:tt)* ) => { ... };
}
Joins two column names together, when one or both inputs might be literal strings representing simple (non-nested) column names. For example:

assert_eq!(joined_column_name!("a.b", "c"), column_name!("a.b").join(&column_name!("c")))

To avoid accidental misuse, at least one argument must be a string literal. Thus, the following invocation would fail to compile:

# use delta_kernel::expressions::joined_column_name;
let s = "s";
let name = joined_column_name!(s, s);