Module error

Module error 

Error types for the history manager module.

Enums

LogHistoryError
Represents errors that can occur when converting commit timestamps to versions.
NearestTimestamp
The nearest retained timestamp on the side of the search bound that an out-of-range search failed against. Engines surface this to users so the error message can point at a valid timestamp.