Available on crate feature
internal-api only.Expand description
Represents a segment of a delta log. LogSegment wraps a set of checkpoint and commit
files.
Re-exports
pub use crate::log_segment_files::LogSegmentFiles;
Structs
- Actions
With Checkpoint Info - Result of reading actions from a log segment, containing both the actions iterator and checkpoint metadata.
- Checkpoint
Read Info - Information about checkpoint reading for data skipping optimization.
- LogSegment
- A
LogSegmentrepresents a contiguous section of the log and is made of checkpoint files and commit files and guarantees the following: 1. Commit file versions will not have any gaps between them. 2. If checkpoint(s) is/are present in the range, only commits with versions greater than the most recent checkpoint version are retained. There will not be a gap between the checkpoint version and the first commit version. 3. All checkpoint_parts must belong to the same checkpoint version, and must form a complete version. Multi-part checkpoints must have all their parts.