pub struct LogSegmentFiles {
pub ascending_commit_files: Vec<ParsedLogPath>,
pub ascending_compaction_files: Vec<ParsedLogPath>,
pub checkpoint_parts: Vec<ParsedLogPath>,
pub latest_crc_file: Option<ParsedLogPath>,
pub latest_commit_file: Option<ParsedLogPath>,
pub max_published_version: Option<Version>,
}Available on crate feature
internal-api only.Expand description
Represents the set of log files found during a listing operation in the Delta log directory.
ascending_commit_files: All commit and staged commit files found, sorted by version. May contain gaps.ascending_compaction_files: All compaction commit files found, sorted by version.checkpoint_parts: All parts of the most recent complete checkpoint (all same version). Empty if no checkpoint found. A version can hold several complete checkpoints; seegroup_checkpoint_partsfor which one this is.latest_crc_file: The CRC file with the highest version, only if version >= checkpoint version.latest_commit_file: The commit file with the highest version, orNoneif no commits were found. This field may be present even whenascending_commit_filesis empty, such as when a checkpoint subsumes all commits. In that case, it is retained because downstream code (e.g. In-Commit Timestamp reading) needs access to the commit file at the snapshot version.max_published_version: The highest published commit file version, orNoneif no published commits were found.
Fields
ascending_commit_files: Vec<ParsedLogPath>ascending_compaction_files: Vec<ParsedLogPath>checkpoint_parts: Vec<ParsedLogPath>latest_crc_file: Option<ParsedLogPath>latest_commit_file: Option<ParsedLogPath>max_published_version: Option<Version>Trait Implementations
Sourceimpl Clone for LogSegmentFiles
impl Clone for LogSegmentFiles
Sourcefn clone(&self) -> LogSegmentFiles
fn clone(&self) -> LogSegmentFiles
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LogSegmentFiles
impl Debug for LogSegmentFiles
Sourceimpl Default for LogSegmentFiles
impl Default for LogSegmentFiles
Sourcefn default() -> LogSegmentFiles
fn default() -> LogSegmentFiles
Returns the “default value” for a type. Read more
impl Eq for LogSegmentFiles
Sourceimpl PartialEq for LogSegmentFiles
impl PartialEq for LogSegmentFiles
impl StructuralPartialEq for LogSegmentFiles