pub struct BufReader { /* private fields */ }arrow-59 and crate feature tokio and (crate features arrow-58 or arrow-59) only.Expand description
An async-buffered reader compatible with the tokio IO traits
Internally this maintains a buffer of the requested size, and uses ObjectStoreExt::get_range
to populate its internal buffer once depleted. This buffer is cleared on seek.
Whilst simple, this interface will typically be outperformed by the native ObjectStore
methods that better map to the network APIs. This is because most object stores have
very high first-byte latencies, on the order of 100-200ms, and so avoiding unnecessary
round-trips is critical to throughput.
Systems looking to sequentially scan a file should instead consider using ObjectStoreExt::get,
or ObjectStore::get_opts, or ObjectStoreExt::get_range to read a particular range.
Systems looking to read multiple ranges of a file should instead consider using
ObjectStore::get_ranges, which will optimise the vectored IO.
Implementations
Sourceimpl BufReader
impl BufReader
Sourcepub fn new(store: Arc<dyn ObjectStore>, meta: &ObjectMeta) -> BufReader
pub fn new(store: Arc<dyn ObjectStore>, meta: &ObjectMeta) -> BufReader
Create a new BufReader from the provided ObjectMeta and ObjectStore
Sourcepub fn with_capacity(
store: Arc<dyn ObjectStore>,
meta: &ObjectMeta,
capacity: usize,
) -> BufReader
pub fn with_capacity( store: Arc<dyn ObjectStore>, meta: &ObjectMeta, capacity: usize, ) -> BufReader
Create a new BufReader from the provided ObjectMeta, ObjectStore, and capacity