pub struct Certificate(/* private fields */);Available on crate feature
arrow-59 and (crate features arrow-58 or arrow-59) and non-WebAssembly only.Expand description
Represents a CA certificate provided by the user.
This is used to configure the client to trust a specific certificate. See Self::from_pem for an example
Implementations
Sourceimpl Certificate
impl Certificate
Sourcepub fn from_pem(pem: &[u8]) -> Result<Certificate, Error>
Available on crate feature cloud only.
pub fn from_pem(pem: &[u8]) -> Result<Certificate, Error>
cloud only.Create a Certificate from a PEM encoded certificate.
Example from a PEM file
let mut buf = Vec::new();
File::open("my_cert.pem").unwrap()
.read_to_end(&mut buf).unwrap();
let cert = Certificate::from_pem(&buf).unwrap();
Sourcepub fn from_pem_bundle(pem_bundle: &[u8]) -> Result<Vec<Certificate>, Error>
Available on crate feature cloud only.
pub fn from_pem_bundle(pem_bundle: &[u8]) -> Result<Vec<Certificate>, Error>
cloud only.Create a collection of Certificate from a PEM encoded certificate
bundle.
Files that contain such collections have extensions such as .crt,
.cer and .pem files.