GetOptions

Struct GetOptions 

pub struct GetOptions {
    pub if_match: Option<String>,
    pub if_none_match: Option<String>,
    pub if_modified_since: Option<DateTime<Utc>>,
    pub if_unmodified_since: Option<DateTime<Utc>>,
    pub range: Option<GetRange>,
    pub version: Option<String>,
    pub head: bool,
    pub extensions: Extensions,
}
Available on crate feature arrow-59 and (crate features arrow-58 or arrow-59) only.
Options for a get request, such as range

Fields

if_match: Option<String>

Request will succeed if the ObjectMeta::e_tag matches otherwise returning Error::Precondition

See https://datatracker.ietf.org/doc/html/rfc9110#name-if-match

Examples:

If-Match: "xyzzy"
If-Match: "xyzzy", "r2d2xxxx", "c3piozzzz"
If-Match: *
if_none_match: Option<String>

Request will succeed if the ObjectMeta::e_tag does not match otherwise returning Error::NotModified

See https://datatracker.ietf.org/doc/html/rfc9110#section-13.1.2

Examples:

If-None-Match: "xyzzy"
If-None-Match: "xyzzy", "r2d2xxxx", "c3piozzzz"
If-None-Match: *
if_modified_since: Option<DateTime<Utc>>

Request will succeed if the object has been modified since

https://datatracker.ietf.org/doc/html/rfc9110#section-13.1.3

if_unmodified_since: Option<DateTime<Utc>>

Request will succeed if the object has not been modified since otherwise returning Error::Precondition

Some stores, such as S3, will only return NotModified for exact timestamp matches, instead of for any timestamp greater than or equal.

https://datatracker.ietf.org/doc/html/rfc9110#section-13.1.4

range: Option<GetRange>

Request transfer of only the specified range of bytes otherwise returning Error::NotModified

https://datatracker.ietf.org/doc/html/rfc9110#name-range

version: Option<String>

Request a particular object version

head: boolextensions: Extensions

Implementation-specific extensions. Intended for use by ObjectStore implementations that need to pass context-specific information (like tracing spans) via trait methods.

These extensions are ignored entirely by backends offered through this crate.

Implementations

Source

impl GetOptions

pub fn check_preconditions(&self, meta: &ObjectMeta) -> Result<(), Error>

Returns an error if the modification conditions on this request are not satisfied

https://datatracker.ietf.org/doc/html/rfc7232#section-6

pub fn new() -> GetOptions

Create a new GetOptions

pub fn with_if_match(self, etag: Option<impl Into<String>>) -> GetOptions

Sets the if_match condition.

See GetOptions::if_match

pub fn with_if_none_match(self, etag: Option<impl Into<String>>) -> GetOptions

Sets the if_none_match condition.

See GetOptions::if_none_match

pub fn with_if_modified_since( self, dt: Option<impl Into<DateTime<Utc>>>, ) -> GetOptions

Sets the if_modified_since condition.

See GetOptions::if_modified_since

pub fn with_if_unmodified_since( self, dt: Option<impl Into<DateTime<Utc>>>, ) -> GetOptions

Sets the if_unmodified_since condition.

See GetOptions::if_unmodified_since

pub fn with_range(self, range: Option<impl Into<GetRange>>) -> GetOptions

Sets the range condition.

See GetOptions::range

pub fn with_version(self, version: Option<impl Into<String>>) -> GetOptions

Sets the version condition.

See GetOptions::version

pub fn with_head(self, head: impl Into<bool>) -> GetOptions

Sets the head condition.

See GetOptions::head

pub fn with_extensions(self, extensions: Extensions) -> GetOptions

Sets the extensions condition.

See GetOptions::extensions