pub struct UpdateVersion {
pub e_tag: Option<String>,
pub version: Option<String>,
}Available on crate feature
arrow-59 and (crate features arrow-58 or arrow-59) only.Expand description
Uniquely identifies a version of an object to update
Stores will use differing combinations of e_tag and version to provide conditional
updates, and it is therefore recommended applications preserve both
Fields
e_tag: Option<String>The unique identifier for the newly created object
version: Option<String>A version indicator for the newly created object