UnaryExpressionOp

Enum UnaryExpressionOp 

#[repr(i32)]
pub enum UnaryExpressionOp { Unspecified = 0, ToJson = 1, }
Available on crate feature declarative-plans only.

Variants



Unspecified = 0



ToJson = 1

Implementations

Source

impl UnaryExpressionOp

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of UnaryExpressionOp.

pub fn from_i32(value: i32) -> Option<UnaryExpressionOp>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a UnaryExpressionOp, or None if value is not a valid variant.

Source

impl UnaryExpressionOp

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.