pub struct VariadicExpression {
pub op: i32,
pub exprs: Vec<Expression>,
}Available on crate feature
declarative-plans only.Fields
op: i32exprs: Vec<Expression>Implementations
Sourceimpl VariadicExpression
impl VariadicExpression
Sourcepub fn op(&self) -> VariadicExpressionOp
pub fn op(&self) -> VariadicExpressionOp
Returns the enum value of op, or the default if the field is set to an invalid enum value.
Sourcepub fn set_op(&mut self, value: VariadicExpressionOp)
pub fn set_op(&mut self, value: VariadicExpressionOp)
Sets op to the provided enum value.