pub enum Func {
Min(MinAgg),
Max(MaxAgg),
MinNonNullBy(MinNonNullByAgg),
MaxNonNullBy(MaxNonNullByAgg),
Sum(SumAgg),
Count(CountAgg),
CountStar(CountStarAgg),
}Available on crate feature
declarative-plans only.Variants
Min(MinAgg)
Max(MaxAgg)
MinNonNullBy(MinNonNullByAgg)
MaxNonNullBy(MaxNonNullByAgg)
Sum(SumAgg)
Count(CountAgg)
CountStar(CountStarAgg)
Implementations
Sourceimpl Func
impl Func
Sourcepub fn merge(
field: &mut Option<Func>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Func>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.