RowTrackingDomainMetadata

Struct RowTrackingDomainMetadata 

pub struct RowTrackingDomainMetadata { /* private fields */ }
Available on crate feature test-utils only.

Implementations

Source

impl RowTrackingDomainMetadata

pub fn get_high_water_mark( snapshot: &Snapshot, engine: &dyn Engine, ) -> DeltaResult<Option<i64>>

Retrieves the row ID high water mark from the Snapshot’s row tracking domain metadata.

This method searches through the snapshot’s log segment for domain metadata actions with the row tracking domain name and extracts the high water mark value.

Returns

Returns Ok(Some(high_water_mark)) if row tracking domain metadata is found, Ok(None) if no row tracking domain metadata exists, or an error if the metadata cannot be parsed or accessed.

Errors

This method will return an error if:

  • The domain metadata configuration cannot be read from the log segment
  • The domain metadata JSON cannot be deserialized into RowTrackingDomainMetadata