pub struct ScanFile {
pub path: String,
pub size: i64,
pub modification_time: i64,
pub stats: Option<Stats>,
pub dv_info: DvInfo,
pub transform: Option<ExpressionRef>,
pub partition_values: HashMap<String, String>,
}Expand description
A ScanFile represents information about one file that needs to be scanned to read a table.
Fields
path: StringPath to the file
size: i64Size of the file
modification_time: i64The time the file was created, as milliseconds since the epoch
stats: Option<Stats>Statistics about the file
dv_info: DvInfoA DvInfo struct, which allows getting the selection vector for this file
transform: Option<ExpressionRef>An optional expression that, if present, must be applied to physical data to convert it to the correct logical format
partition_values: HashMap<String, String>a HashMap<String, String> which map partition names to the value they have in this file