GetStructField

Trait GetStructField 

pub trait GetStructField {
    // Required method
    fn get_struct_field(name: impl Into<String>) -> StructField;
}
Available on crate feature internal-api only.
The delta_kernel_derive::ToSchema macro uses this to convert a struct field’s name + type into a StructField definition. A blanket impl for Option<T: ToDataType> supports nullable struct fields, which otherwise default to non-nullable.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: ToDataType> GetStructField for Option<T>

Implementors