PredicateEvaluator

Trait PredicateEvaluator 

pub trait PredicateEvaluator: AsAny {
    // Required method
    fn evaluate(
        &self,
        batch: &dyn EngineData,
    ) -> DeltaResult<Box<dyn EngineData>>;
}
Trait for implementing a Predicate evaluator.

It contains one Predicate which can be evaluated on multiple ColumnarBatches. Connectors can implement this trait to optimize the evaluation using the connector specific capabilities.

Required Methods

fn evaluate(&self, batch: &dyn EngineData) -> DeltaResult<Box<dyn EngineData>>

Evaluate the predicate on a given EngineData.

Produces one boolean value for each row of the input.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl PredicateEvaluator for DefaultPredicateEvaluator

Available on crate feature arrow-expression and crate feature default-engine-base and (crate features arrow-conversion or declarative-plans or default-engine-base) only.