Module transaction

Module transaction 

Modules

builderinternal-api
Builder modules for transaction construction.
create_tableinternal-api
Create table transaction types and entry point (internal API).
data_layoutinternal-api
Data layout configuration for Delta tables.

Structs

AlterTable
Marker type for alter-table (schema evolution) transactions.
CommittedTransaction
This is the result of a successfully committed Transaction. One can retrieve the post_commit_stats, commit version, and optionally the post-commit snapshot from this struct.
ConflictedTransaction
This is the result of a conflicted Transaction. One can retrieve the conflict version from this struct. In the future a rebase API will be provided (issue #1389).
CreateTable
Marker type for create-table transactions.
ExistingTable
Marker type for transactions on existing tables.
PostCommitStats
Kernel exposes information about the state of the table that engines might want to use to trigger actions like checkpointing or log compaction. This struct holds that information.
RetryableTransaction
A transaction that failed to commit due to a retryable error (e.g. IO error). The transaction can be recovered with RetryableTransaction::transaction and retried without rebasing. The associated error can be inspected via RetryableTransaction::error.
Transaction
A transaction represents an in-progress write to a table. After creating a transaction, changes to the table may be staged via the transaction methods before calling commit to commit the changes to the table.
WriteContext
A write context for a specific partition or an unpartitioned table. Created by Transaction::partitioned_write_context or Transaction::unpartitioned_write_context.

Enums

CommitResult
The result of attempting to commit this transaction. If the commit was successful/conflicted/retryable, the result is Ok(CommitResult), otherwise, if a nonrecoverable error occurred, the result is Err(Error).

Traits

SupportsDataFiles
Marker trait for transaction states that support data file operations.

Type Aliases

AlterTableTransaction
A type alias for alter-table transactions.