pub struct CommittedTransaction { /* private fields */ }Expand description
This is the result of a successfully committed Transaction. One can retrieve the post_commit_stats, commit version, and optionally the post-commit snapshot from this struct.
Implementations
Sourceimpl CommittedTransaction
impl CommittedTransaction
Sourcepub fn commit_version(&self) -> Version
pub fn commit_version(&self) -> Version
The version of the table that was just sucessfully committed
Sourcepub fn post_commit_stats(&self) -> &PostCommitStats
pub fn post_commit_stats(&self) -> &PostCommitStats
The PostCommitStats for this transaction
Sourcepub fn post_commit_snapshot(&self) -> Option<&SnapshotRef>
pub fn post_commit_snapshot(&self) -> Option<&SnapshotRef>
The SnapshotRef of the table after this transaction was committed.