pub struct CheckpointVisitor { /* private fields */ }Available on crate feature
internal-api only.Expand description
Extracts the first checkpoint action found, leaving checkpoint as None if a batch has
none. The action is an array of single-key tagged objects, each one of the metadata actions
embedded in an adaptiveMetadata manifest commit.