default-engine-native-tls or default-engine-rustls or arrow-conversion) and crate feature arrow-conversion only.Expand description
Conversions between kernel schema types and arrow schema types.
Two directions, used at the engine <-> kernel boundary:
-
arrow -> kernel (
TryFromArrow/TryIntoKernel): an example usage is converting a checkpoint Parquet file’s Arrow footer schema into a kernelStructTypeduring log replay. -
kernel -> arrow (
TryFromKernel/TryIntoArrow): an example usage is materializing a kernelStructTypeas anArrowSchemato build aRecordBatchon the write path.
These conversions can be used on both logical and physical schemas. E.g. when writing a parquet
file, the default engine converts the physical kernel schema to an Arrow schema and writes the
data. When transforming physical data to logical data via an
Expression,
DefaultExpressionEvaluator
converts the logical schema to an Arrow schema as the output schema.
Modules
Traits
- TryFrom
Arrow - Convert an arrow type into a kernel type (a similar
TryIntoKerneltrait is automatically implemented for all types that implementTryFromArrow) - TryFrom
Kernel - Convert a kernel type into an arrow type (a similar
TryIntoArrowtrait is automatically implemented for all types that implementTryFromKernel) - TryInto
Arrow - Convert a kernel type into an arrow type (automatically implemented for all types that
implement
TryFromKernel) - TryInto
Kernel - Convert an arrow type into a kernel type (automatically implemented for all types that
implement
TryFromArrow)