pub fn reader_options() -> ArrowReaderOptionsAvailable on crate feature
internal-api and (crate features arrow-conversion or declarative-plans or default-engine-base) only.Expand description
Returns the standard ArrowReaderOptions for all default engine parquet reads.
Skipping the embedded Arrow IPC schema avoids dependence on Arrow-specific metadata and ensures that type resolution is driven by the kernel schema rather than the file’s schema.