Definitions of errors that the delta kernel can encounter
Enums
- Error
- All the types of errors that the kernel can run into
Type Aliases
- Delta
Result - A
std::result::Resultthat has the kernelErroras the error variant - Delta
Result Iterator - A boxed,
Senditerator ofDeltaResult<T>items. - Delta
Result Iterator Static 'staticcounterpart toDeltaResultIteratorfor cases where the iterator does not reference borrowed data.