Module expressions

Module expressions 

Definitions and functions to create and manipulate kernel expressions

Macros

column_expr
column_expr_ref
column_name
Creates a nested column name whose field names are all simple column names (containing only alphanumeric characters and underscores), delimited by dots. This macro is provided as a convenience for the common case where the caller knows the column name contains only simple field names and that splitting by periods is safe:
column_pred
joined_column_expr
joined_column_name
Joins two column names together, when one or both inputs might be literal strings representing simple (non-nested) column names. For example:

Structs

ArrayData
BinaryExpression
BinaryPredicate
ColumnName
A (possibly nested) column name.
DecimalData
FieldTransform
A transformation affecting a single field (one pieces of a Transform). The transformation could insert 0+ new fields after the target, or could replace the target with 0+ a new fields).
JunctionPredicate
MapData
MapToStructExpression
Transforms a Map<String, String> column into a struct whose schema is provided by the evaluator’s output type (via result_type). Each row in the map column becomes one row in the output struct column: a key -> value mapping in the map means the struct field named key receives value, parsed into the field’s target type using Delta’s partition value serialization rules (PrimitiveType::parse_scalar).
OpaqueExpression
OpaquePredicate
ParseJsonExpression
An expression that parses a JSON string into a struct with the given schema. This is the inverse of ToJson - it converts a JSON-encoded string column into a struct column.
StructData
Transform
A transformation that efficiently represents sparse modifications to struct schemas.
UnaryExpression
UnaryPredicate
VariadicExpression

Enums

BinaryExpressionOp
A binary expression operator.
BinaryPredicateOp
A binary predicate operator.
Expression
A SQL expression.
JunctionPredicateOp
A junction (AND/OR) predicate operator.
Predicate
A SQL predicate.
Scalar
A single value, which can be null. Used for representing literal values in Expressions.
UnaryExpressionOp
A unary expression operator.
UnaryPredicateOp
A unary predicate operator.
VariadicExpressionOp
A variadic expression operator.

Traits

OpaqueExpressionOp
An opaque expression operation (ie defined and implemented by the engine).
OpaquePredicateOp
An opaque predicate operation (ie defined and implemented by the engine).

Type Aliases

ExpressionRef
OpaqueExpressionOpRef
A shared reference to an OpaqueExpressionOp instance.
OpaquePredicateOpRef
A shared reference to an OpaquePredicateOp instance.
PredicateRef
ScalarExpressionEvaluator
A kernel-supplied scalar expression evaluator which in particular can convert column references (i.e. Expression::Column) to Scalar values. OpaqueExpressionOp::eval_expr_scalar and OpaquePredicateOp::eval_pred_scalar rely on this evaluator.