Definitions and functions to create and manipulate kernel expressions
Macros
- column_
expr - column_
expr_ ref - column_
name - Creates a nested column name whose field names are all simple column names (containing only alphanumeric characters and underscores), delimited by dots. This macro is provided as a convenience for the common case where the caller knows the column name contains only simple field names and that splitting by periods is safe:
- column_
pred - joined_
column_ expr - joined_
column_ name - Joins two column names together, when one or both inputs might be literal strings representing simple (non-nested) column names. For example:
Structs
- Array
Data - Binary
Expression - Binary
Predicate - Column
Name - A (possibly nested) column name.
- Decimal
Data - Field
Transform - A transformation affecting a single field (one pieces of a
Transform). The transformation could insert 0+ new fields after the target, or could replace the target with 0+ a new fields). - Junction
Predicate - MapData
- MapTo
Struct Expression - Transforms a
Map<String, String>column into a struct whose schema is provided by the evaluator’s output type (viaresult_type). Each row in the map column becomes one row in the output struct column: akey->valuemapping in the map means the struct field namedkeyreceivesvalue, parsed into the field’s target type using Delta’s partition value serialization rules (PrimitiveType::parse_scalar). - Opaque
Expression - Opaque
Predicate - Parse
Json Expression - An expression that parses a JSON string into a struct with the given schema.
This is the inverse of
ToJson- it converts a JSON-encoded string column into a struct column. - Struct
Data - Transform
- A transformation that efficiently represents sparse modifications to struct schemas.
- Unary
Expression - Unary
Predicate - Variadic
Expression
Enums
- Binary
Expression Op - A binary expression operator.
- Binary
Predicate Op - A binary predicate operator.
- Expression
- A SQL expression.
- Junction
Predicate Op - A junction (AND/OR) predicate operator.
- Predicate
- A SQL predicate.
- Scalar
- A single value, which can be null. Used for representing literal values in Expressions.
- Unary
Expression Op - A unary expression operator.
- Unary
Predicate Op - A unary predicate operator.
- Variadic
Expression Op - A variadic expression operator.
Traits
- Opaque
Expression Op - An opaque expression operation (ie defined and implemented by the engine).
- Opaque
Predicate Op - An opaque predicate operation (ie defined and implemented by the engine).
Type Aliases
- Expression
Ref - Opaque
Expression OpRef - A shared reference to an
OpaqueExpressionOpinstance. - Opaque
Predicate OpRef - A shared reference to an
OpaquePredicateOpinstance. - Predicate
Ref - Scalar
Expression Evaluator - A kernel-supplied scalar expression evaluator which in particular can convert column references
(i.e.
Expression::Column) toScalarvalues.OpaqueExpressionOp::eval_expr_scalarandOpaquePredicateOp::eval_pred_scalarrely on this evaluator.