Error types for the history manager module.
Enums
- LogHistory
Error - Represents errors that can occur when converting commit timestamps to versions.
- Nearest
Timestamp - The nearest retained timestamp on the side of the search bound that an out-of-range search failed against. Engines surface this to users so the error message can point at a valid timestamp.