pub struct KernelPredicateEvaluatorDefaults;Expand description
A collection of provided methods from the KernelPredicateEvaluator trait, factored out to
allow reuse by multiple bool-output predicate evaluator implementations.
Implementations
Sourceimpl KernelPredicateEvaluatorDefaults
impl KernelPredicateEvaluatorDefaults
Sourcepub fn eval_pred_scalar(val: &Scalar, inverted: bool) -> Option<bool>
pub fn eval_pred_scalar(val: &Scalar, inverted: bool) -> Option<bool>
Directly evaluates a boolean scalar. See KernelPredicateEvaluator::eval_pred_scalar.
Sourcepub fn eval_pred_scalar_is_null(val: &Scalar, inverted: bool) -> Option<bool>
pub fn eval_pred_scalar_is_null(val: &Scalar, inverted: bool) -> Option<bool>
Directly null-tests a scalar. See KernelPredicateEvaluator::eval_pred_scalar_is_null.
Sourcepub fn partial_cmp_scalars(
ord: Ordering,
a: &Scalar,
b: &Scalar,
inverted: bool,
) -> Option<bool>
pub fn partial_cmp_scalars( ord: Ordering, a: &Scalar, b: &Scalar, inverted: bool, ) -> Option<bool>
A (possibly inverted) partial comparison of two scalars using SQL/logical semantics.
Returns None if the scalars are incomparable (different types, NULL values, or
unsupported types like Struct/Array/Map).
NOTE: This implements SQL NULL semantics where NULL is incomparable to everything,
including itself. For physical/structural comparison of query plans, use == on
Scalar directly (which provides physical equality).
Sourcepub fn eval_pred_binary_scalars(
op: BinaryPredicateOp,
left: &Scalar,
right: &Scalar,
inverted: bool,
) -> Option<bool>
pub fn eval_pred_binary_scalars( op: BinaryPredicateOp, left: &Scalar, right: &Scalar, inverted: bool, ) -> Option<bool>
Directly evaluates a boolean comparison. See
KernelPredicateEvaluator::eval_pred_binary_scalars.
Sourcepub fn finish_eval_pred_junction(
op: JunctionPredicateOp,
preds: &mut dyn Iterator<Item = Option<bool>>,
inverted: bool,
) -> Option<bool>
pub fn finish_eval_pred_junction( op: JunctionPredicateOp, preds: &mut dyn Iterator<Item = Option<bool>>, inverted: bool, ) -> Option<bool>
Finishes evaluating a (possibly inverted) junction operation. See
KernelPredicateEvaluator::finish_eval_pred_junction.
The inputs were already inverted by the caller, if needed.
With AND (OR), any FALSE (TRUE) input dominates, forcing a FALSE (TRUE) output. If there was no dominating input, then any NULL input forces NULL output. Otherwise, return the non-dominant value. Inverting the operation also inverts the dominant value.