pub trait HasSelectionVector {
// Required method
fn has_selected_rows(&self) -> bool;
}Available on crate feature
internal-api only.Expand description
This trait is used to determine if a processor’s output contains any selected rows. This is used to filter out batches with no selected rows from the log replay results.
Required Methods
Sourcefn has_selected_rows(&self) -> bool
fn has_selected_rows(&self) -> bool
Check if the selection vector contains at least one selected row
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".