This is the result of a conflicted Transaction. One can retrieve the conflict version from
this struct. In the future a rebase API will be provided (issue #1389).
Kernel exposes information about the state of the table that engines might want to use to
trigger actions like checkpointing or log compaction. This struct holds that information.
A transaction that failed to commit due to a retryable error (e.g. IO error). The transaction
can be recovered with RetryableTransaction::transaction and retried without rebasing. The
associated error can be inspected via RetryableTransaction::error.
A transaction represents an in-progress write to a table. After creating a transaction, changes
to the table may be staged via the transaction methods before calling commit to commit the
changes to the table.
The result of attempting to commit this transaction. If the commit was
successful/conflicted/retryable, the result is Ok(CommitResult), otherwise, if a nonrecoverable
error occurred, the result is Err(Error).