pub struct PostCommitStats {
pub commits_since_checkpoint: u64,
pub commits_since_log_compaction: u64,
}Expand description
Kernel exposes information about the state of the table that engines might want to use to trigger actions like checkpointing or log compaction. This struct holds that information.
Fields
commits_since_checkpoint: u64The number of commits since this table has been checkpointed. Note that commit 0 is considered a checkpoint for the purposes of this computation.
commits_since_log_compaction: u64The number of commits since the log has been compacted on this table. Note that a checkpoint is considered a compaction for the purposes of this computation. Thus this is really the number of commits since a compaction OR a checkpoint.