pub trait SupportsDataFiles { }Expand description
Marker trait for transaction states that support data file operations.
Only transaction types that implement this trait can access methods for adding, removing, or
updating data files. This prevents compile-time misuse by states like AlterTable that
only perform metadata-only commits.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".